summaryrefslogtreecommitdiffstats
path: root/Source/cmCommands.h
diff options
context:
space:
mode:
Diffstat (limited to 'Source/cmCommands.h')
-rw-r--r--Source/cmCommands.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/Source/cmCommands.h b/Source/cmCommands.h
index 5ec0ed1..878ded3 100644
--- a/Source/cmCommands.h
+++ b/Source/cmCommands.h
@@ -21,10 +21,12 @@
class cmCommand;
/**
* Global function to return all compiled in commands.
* To add a new command edit cmCommands.cxx and add your command.
* It is up to the caller to delete the commands created by this
* call.
*/
+void GetBootstrapCommands(std::list<cmCommand*>& commands);
void GetPredefinedCommands(std::list<cmCommand*>& commands);
@@ -21,10 +21,12 @@
/**
* Global function to return all compiled in commands.
- * To add a new command edit cmCommands.cxx and add your command.
+ * To add a new command edit cmCommands.cxx or cmBootstrapCommands.cxx
+ * and add your command.
* It is up to the caller to delete the commands created by this
* call.